
export interface ImageParams {
	title: string;
	image: {
		url: string;
		title: string;
		width: number;
		height: number;
	};
	text: TextParams[];
	text_style: {
		font_size: number;
		font_family: string;
		font_weight: 100 | 200 | 300 | 400 | 500 | 600 | 700 | 800 | 900;
		fill: string;
		stroke: string;
		stroke_width: number;
	}
}

export interface TextParams {
	text: string;
	top: number;
	left: number;
}

export const render_svg = (params: ImageParams) => `
<?xml version="1.0" encoding="UTF-8"?>
<svg version="1.1"
	width="${params.image.width}" height="${params.image.height}"
	xmlns="http://www.w3.org/2000/svg"
	xmlns:xlink="http://www.w3.org/1999/xlink"
	style="user-select: none">
	<title>${params.title}</title>

	<image x="0" y="0"
		width="${params.image.width}" height="${params.image.height}"
		href="${params.image.url}"
		xlink:href="${params.image.url}">
		<title>${params.image.title}</title>
	</image>
	${params.text.map((text) => `
	<text x="${text.left}" y="${text.top}"
		text-anchor="middle"
		font-size="${params.text_style.font_size}"
		font-family="${params.text_style.font_family}"
		font-weight="${params.text_style.font_weight}"
		stroke="${params.text_style.stroke}"
		stroke-width="${params.text_style.stroke_width}"
		fill="${params.text_style.fill}"
		>${text.text}</text>`
	).join('')}
</svg>`.trimStart();
